require 'rspec'
require 'ramper_file_metrics'

describe 'RamperFileMetrics' do

  context '.combine_authors' do
    it 'should return the same table if it has no dupes in the given field: email' do
      orig = [{ :count => 2, :name => 'name', :email => 'email1' },
              { :count => 2, :name => 'name', :email => 'email2' },
              { :count => 2, :name => 'name', :email => 'email3' }]
      RamperFileMetrics.combine_authors(orig, :email).should == orig
    end
    it 'should return the same table if it has no dupes in the given field: name' do
      orig = [{ :count => 2, :name => 'name1', :email => 'email' },
              { :count => 2, :name => 'name2', :email => 'email' },
              { :count => 2, :name => 'name3', :email => 'email' }]
      RamperFileMetrics.combine_authors(orig, :name).should == orig
    end

    it 'should combine elements if it has dupes in the given field: email' do
      orig = [{ :count => 1, :name => 'name1', :email => 'email' },
              { :count => 2, :name => 'name2', :email => 'email' },
              { :count => 3, :name => 'name3', :email => 'email' }]
      new  = [{ :count => 6, :name => 'name3', :email => 'email' }]
      RamperFileMetrics.combine_authors(orig, :email).should == new
    end

    it 'should combine elements if it has dupes in the given field: name' do
      orig = [{ :count => 1, :name => 'name', :email => 'email1' },
              { :count => 2, :name => 'name', :email => 'email2' },
              { :count => 3, :name => 'name', :email => 'email3' }]
      new  = [{ :count => 6, :name => 'name', :email => 'email3' }]
      RamperFileMetrics.combine_authors(orig, :name).should == new
    end
  end

  context '.author_stats' do

    it 'should have resolved duplicates in either field' do
      RamperFileMetrics.stub(:get_git_author_stats).and_return(["     8	j1 <j>",
                                                                "     5	a <a1>",
                                                                "     3	a <a2>",
                                                                "     1	j2 <j>"])
      RamperFileMetrics.author_stats('').should == ["j1 <j>", 2]
    end

    it 'should have combined by email first' do
      RamperFileMetrics.stub(:get_git_author_stats).and_return(["     8	j1 <j>",
                                                                "     5	a1 <a1>",
                                                                "     3	a2 <a2>",
                                                                "     4	a1 <a2>",
                                                                "     1	j2 <j>"])
      RamperFileMetrics.author_stats('').should == ["a1 <a2>", 2]
    end
  end
end